@@ -47,7 +47,7 @@ class GifAscii:
                 for i in range(height):
                     for j in range(width):
                         pixel = image.getpixel((j, i))
-                        r, g, b = pixel
+                        r, g, b = self.get_rgb(pixel, image)
                         op_buffer += '\x1b[38;2;{};{};{}m'.format(r, g, b)
                         op_buffer += str(self.chars[random.randint(0, len(self.chars)-1)])
                     op_buffer += '\n'
@@ -64,13 +64,7 @@ class GifAscii:
         for i in range(height):
             for j in range(width):
                 pixel = image.getpixel((j, i))
-                if isinstance(pixel, int):
-                    r, g, b = 0, 0, pixel
-                else:
-                    try:
-                        r, g, b, _ = pixel
-                    except Exception as e:
-                        r, g, b = pixel
+                r, g, b = self.get_rgb(pixel, image)
                 op_buffer += '\x1b[38;2;{};{};{}m'.format(r, g, b)
                 op_buffer += str(self.chars[random.randint(0, len(self.chars)-1)])
             op_buffer += '\n'
@@ -107,6 +101,18 @@ class GifAscii:
                 pass
         else:
             self.play_gif(frames)
+    
+    def get_rgb(self, pixel, image):
+        if isinstance(pixel, int):
+            palette = image.getpalette()
+            color_idx = pixel * 3
+            r, g, b = palette[color_idx:color_idx+3]
+        else:
+            if len(pixel) == 4:
+                r, g, b, _ = pixel
+            else:
+                r, g, b = pixel
+        return r, g, b
 
         
     def extract_frames(self):
@@ -122,8 +128,8 @@ class GifAscii:
         while frame:
             ansi = self._get_gif_frame_ansi(frame)
             frames_created += 1
-            sys.stdout.write(ansi)
             clear(self.op_width, self.tsize.lines)
+            sys.stdout.write(ansi)
             try:
                 frame.seek(frames_created)
             except EOFError:
